@@ -43,7 +43,7 @@ class Entity(object):
     Represents an entity to be monitored.
     """
 
-    def __init__(self, id, label, ip_addresses, driver, extra=None):
+    def __init__(self, id, label, ip_addresses, uri, driver, agent_id=None, extra=None):
         """
         @type label: C{str}
         @param label: Object label (must be unique per container).
@@ -54,14 +54,22 @@ class Entity(object):
         @type ip_addresses: C{list}
         @param ip_addresses: List of String aliases to IP Addresses tuples.
 
+        @type uri: C{str}
+        @param uri: A non-user settable attribute that ties entities to foreign objects.
+
         @type driver: C{StorageDriver}
         @param driver: StorageDriver instance.
+
+        @type agent_id: C{str}
+        @param agent_id: Agent id, links and entity to an agent.
         """
         self.id = id
         self.label = label
         self.extra = extra or {}
+        self.uri = uri
         self.ip_addresses = ip_addresses or []
         self.driver = driver
+        self.agent_id = agent_id
 
     def update(self, data):
         self.driver.update_entity(entity=self, data=data)
@@ -145,13 +153,14 @@ class NotificationType(object):
 
 
 class Alarm(object):
-    def __init__(self, id, check_id, criteria, driver, entity_id,
+    def __init__(self, id, check_id, criteria, driver, entity_id, label=None,
                  notification_plan_id=None):
         self.id = id
         self.check_id = check_id
         self.criteria = criteria
         self.driver = driver
         self.notification_plan_id = notification_plan_id
+        self.label = label
         self.entity_id = entity_id
 
     def update(self, data):
@@ -161,7 +170,7 @@ class Alarm(object):
         return self.driver.delete_alarm(self)
 
     def __repr__(self):
-        return ('<Alarm: id=%s ...>' % (self.id)).encode('utf-8')
+        return ('<Alarm: id=%s, label=%s ...>' % (self.id, self.label)).encode('utf-8')
 
 
 class Check(object):
@@ -342,7 +351,7 @@ class MonitoringDriver(object):
         raise NotImplementedError(
             'delete_check not implemented for this driver')
 
-    def delete_alarm(self, check):
+    def delete_alarm(self, alarm):
         raise NotImplementedError(
             'delete_alarm not implemented for this driver')
 
