@@ -387,7 +387,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def _to_alarm(self, alarm, value_dict):
         return Alarm(id=alarm['id'], check_id=alarm['check_id'],
             criteria=alarm['criteria'],
-            notification_plan_id=alarm['notification_plan_id'],
+            notification_plan_id=alarm.get('notification_plan_id', None), label=alarm.get('label', None),
             driver=self, entity_id=value_dict['entity_id'])
 
     def list_alarms(self, entity, ex_next_marker=None):
@@ -428,6 +428,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def create_alarm(self, entity, **kwargs):
         data = {'who': kwargs.get('who'),
                 'why': kwargs.get('why'),
+                'label': kwargs.get('label'),
                 'check_id': kwargs.get('check_id'),
                 'criteria': kwargs.get('criteria'),
                 'notification_plan_id': kwargs.get('notification_plan_id')}
@@ -641,8 +642,9 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         if ipaddrs is not None:
             for key in ipaddrs.keys():
                 ips.append((key, ipaddrs[key]))
-        return Entity(id=entity['id'], label=entity['label'],
-                      extra=entity['metadata'], driver=self, ip_addresses=ips)
+        return Entity(id=entity['id'], label=entity['label'], uri=entity.get('uri', None),
+                      extra=entity['metadata'], agent_id=entity.get('agent_id', None),
+                      driver=self, ip_addresses=ips)
 
     def delete_entity(self, entity, **kwargs):
         return self._delete(url="/entities/%s" % (entity.id),
@@ -658,8 +660,10 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def create_entity(self, **kwargs):
         data = {'who': kwargs.get('who'),
                 'why': kwargs.get('why'),
+                'uri': kwargs.get('uri'),
                 'ip_addresses': kwargs.get('ip_addresses', {}),
                 'label': kwargs.get('label'),
+                'agent_id': kwargs.get('agent_id'),
                 'metadata': kwargs.get('extra', {})}
 
         return self._create("/entities", data=data, coerce=self.get_entity)
